@@ -1,6 +1,15 @@
 from __future__ import print_function
 
 def init_napoleon_colab():
+    import os
+    stream = os.popen('pip install dropbox')
+    output = stream.read()
+    print(output)
+
+    stream = os.popen('pip install plotly==4.7.1')
+    output = stream.read()
+    print(output)
+
     from napoleontoolbox.signal import signal_utility
     from napoleontoolbox.analyzer import minutely_market, hourly_market, market
     from datetime import datetime
@@ -21,14 +30,7 @@ def init_napoleon_colab():
     import plotly
     from plotly.offline import iplot
 
-    import os
-    stream = os.popen('pip install dropbox')
-    output = stream.read()
-    print(output)
 
-    stream = os.popen('pip install plotly==4.7.1')
-    output = stream.read()
-    print(output)
 
     def configure_plotly_browser_state():
       import IPython
@@ -49,16 +51,3 @@ def init_napoleon_colab():
     IPython.get_ipython().events.register('pre_run_cell', configure_plotly_browser_state)
 
 
-def plot_dataframe(data):
-    import plotly.graph_objs as go
-    import plotly
-    from plotly.offline import iplot
-    data_list = []
-    for me_commo in data.columns:
-        trace_sig = go.Scatter(
-            x=data.index,
-            y=data[me_commo],
-            name=me_commo,
-            opacity=0.8)
-        data_list.append(trace_sig)
-    iplot(data_list)
\ No newline at end of file
